Learn R Programming

ROptEst (version 1.0)

CniperPointPlot: Wrapper function for cniperPointPlot - Computation and Plot of Cniper Contamination and Cniper Points

Description

The wrapper CniperPointPlot (capital C!) takes most of arguments to the cniperPointPlot (lower case c!) function by default and gives a user possibility to run the function with low number of arguments.

Usage

CniperPointPlot(fam, ..., lower = getdistrOption("DistrResolution"), upper = 1 - getdistrOption("DistrResolution"), with.legend = TRUE, rescale = FALSE, withCall = TRUE)

Arguments

fam
object of class L2ParamFamily
...
additional parameters (in particular to be passed on to plot)
lower
the lower end point of the contamination interval
upper
the upper end point of the contamination interval
with.legend
the flag for showing the legend of the plot
rescale
the flag for rescaling the axes for better view of the plot
withCall
the flag for the call output

Value

invisible(NULL)

Details

Calls cniperPointPlot with suitably chosen defaults; if withCall == TRUE, the call to cniperPointPlot is returned.

Examples

Run this code
L2fam <- NormLocationScaleFamily()
CniperPointPlot(fam=L2fam, main = "Normal location and scale", 
                lower = 0, upper = 2.5, withCall = FALSE)

Run the code above in your browser using DataLab