Learn R Programming

ROptEst (version 0.5.0)

ParamFamily-class: Parametric family of probability measures.

Description

Class of parametric families of probability measures.

Arguments

Objects from the Class

Objects can be created by calls of the form new("ParamFamily", ...). More frequently they are created via the generating function ParamFamily.

Extends

Class "ProbFamily", directly.

concept

parameteric family

See Also

Distribution-class

Examples

Run this code
F1 <- new("ParamFamily") # prototype
plot(F1)

Run the code above in your browser using DataLab