Objects from the Class
Objects can be created by calls of the form new("PosDefSymmMatrix", ...).
More frequently they are created via the generating function
PosDefSymmMatrix.Extends
Class "matrix", from data part.
Class "structure", by class "matrix".
Class "array", by class "matrix".
Class "vector", by class "matrix", with explicit coerce.
Class "vector", by class "matrix", with explicit coerce.concept
- positive-definite matrix
- symmetric matrix