Learn R Programming

ROptEst (version 1.0)

asAnscombe-class: Asymptotic Anscombe risk

Description

Class of asymptotic Anscombe risk which is the ARE (asymptotic relative efficiency) in the ideal model obtained by an optimal bias robust IC .

Arguments

Objects from the Class

Objects can be created by calls of the form new("asAnscombe", ...). More frequently they are created via the generating function asAnscombe.

Slots

Extends

Class "asRiskwithBias", directly. Class "asRisk", by class "asRiskwithBias". Class "RiskType", by class "asRisk".

Methods

References

Hampel et al. (1986) Robust Statistics. The Approach Based on Influence Functions. New York: Wiley. Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

asRisk-class, asAnscombe

Examples

Run this code
new("asAnscombe")

Run the code above in your browser using DataLab