Class of standardized asymptotic bias; i.e.,
the neighborhood radius is omitted respectively, set to $1$.
Arguments
Objects from the Class
Objects can be created by calls of the form new("asBias", ...).
More frequently they are created via the generating function
asBias.
Extends
Class "asRisk", directly.
Class "RiskType", by class "asRisk".
concept
asymptotic bias
risk
References
Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.
Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness.
Bayreuth: Dissertation.