Class of asymptotic Hampel risk which is
the trace of the asymptotic covariance subject to
a given bias bound (bound on gross error sensitivity).
Arguments
Objects from the Class
Objects can be created by calls of the form new("asHampel", ...).
More frequently they are created via the generating function
asHampel.
Extends
Class "asRisk", directly.
Class "RiskType", by class "asRisk".
concept
Hampel risk
risk
References
Hampel et al. (1986) Robust Statistics.
The Approach Based on Influence Functions. New York: Wiley.
Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.
Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness.
Bayreuth: Dissertation.