Learn R Programming

ROptEst (version 1.0)

asL1-class: Asymptotic mean absolute error

Description

Class of asymptotic mean absolute error.

Arguments

Objects from the Class

Objects can be created by calls of the form new("asL1", ...). More frequently they are created via the generating function asL1.

Slots

Extends

Class "asGRisk", directly. Class "asRiskwithBias", by class "asGRisk". Class "asRisk", by class "asRiskwithBias". Class "RiskType", by class "asGRisk".

Methods

No methods defined with class "asL1" in the signature.

References

Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22, 201-223.

See Also

asGRisk-class, asMSE, asMSE-class, asL4-class, asL1

Examples

Run this code
new("asMSE")

Run the code above in your browser using DataLab