Learn R Programming

ROptEst (version 0.5.0)

checkIC: Generic Function for Checking ICs

Description

Generic function for checking centering and Fisher consistency of ICs.

Usage

checkIC(IC, L2Fam, ...)

Arguments

IC
object of class "IC"
L2Fam
L2-differentiable family of probability measures.
...
additional parameters

Value

  • The maximum deviation from the IC properties is returned.

concept

influence curve

Details

The precisions of the centering and the Fisher consistency are computed.

References

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer. Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

L2ParamFamily-class, IC-class

Examples

Run this code
IC1 <- new("IC")
checkIC(IC1)

Run the code above in your browser using DataLab