evalIC: Generic function for evaluating ICs
Description
Generic function for evaluating ICs.Arguments
x
numeric vector or matrix
Value
- In case
x is numeric a vector and in case x
is matrix a matrix is returned.
Details
The list of random variables contained in the slot Curve
is evaluated at x.References
Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.
Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness.
Bayreuth: Dissertation.