Learn R Programming

ROptEst (version 1.0)

getAsRisk: Generic Function for Computation of Asymptotic Risks

Description

Generic function for the computation of asymptotic risks. This function is rarely called directly. It is used by other functions.

Usage

getAsRisk(risk, L2deriv, neighbor, biastype, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk,L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, Finfo, trafo, z.start, A.start, maxiter, tol, warn, verbose = NULL, ...) "getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, Finfo, trafo, z.start, A.start, maxiter, tol, warn, verbose = NULL, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent, stand, Distr, trafo = NULL, V.comp =  matrix(TRUE, ncol = nrow(stand), nrow = nrow(stand)), w, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype, clip, cent, stand, Distr, trafo = NULL, V.comp =  matrix(TRUE, ncol = nrow(stand), nrow = nrow(stand)), w, ...) "getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, FI, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype, clip, cent, stand, Distr, trafo = NULL, V.comp =  matrix(TRUE, ncol = nrow(stand), nrow = nrow(stand)), FI, w, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo, ...)

Arguments

risk
object of class "asRisk".
L2deriv
L2-derivative of some L2-differentiable family of probability distributions.
neighbor
object of class "Neighborhood".
biastype
object of class "ANY".
...
additional parameters; often used to enable flexible calls.
clip
optimal clipping bound.
cent
optimal centering constant.
stand
standardizing matrix.
Finfo
matrix: the Fisher Information of the parameter.
trafo
matrix: transformation of the parameter.
Distr
object of class "Distribution".
DistrSymm
object of class "DistributionSymmetry".
L2derivSymm
object of class "FunSymmList".
L2derivDistrSymm
object of class "DistrSymmList".
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
maxiter
the maximum number of iterations
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.
normtype
object of class "NormType".
V.comp
matrix: indication which components of the standardizing matrix have to be computed.
w
object of class RobWeight; current weight
FI
trace of the respective Fisher Information
verbose
logical: if TRUE some diagnostics are printed out.

Value

Methods

Details

This function is rarely called directly. It is used by other functions/methods.

References

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22, 201-223.

Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

asRisk-class