Learn R Programming

ROptEst (version 1.0)

getFixRobIC: Generic Function for the Computation of Optimally Robust ICs

Description

Generic function for the computation of optimally robust ICs in case of robust models with fixed neighborhoods. This function is rarely called directly.

Usage

getFixRobIC(Distr, risk, neighbor, ...)
"getFixRobIC"(Distr, risk, neighbor, sampleSize, upper, lower, maxiter, tol, warn, Algo, cont)

Arguments

Distr
object of class "Distribution".
risk
object of class "RiskType".
neighbor
object of class "Neighborhood".
...
additional parameters.
sampleSize
integer: sample size.
upper
upper bound for the optimal clipping bound.
lower
lower bound for the optimal clipping bound.
maxiter
the maximum number of iterations.
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.
Algo
"A" or "B".
cont
"left" or "right".

Value

Methods

Details

Computation of the optimally robust IC in sense of Huber (1968) which is also treated in Kohl (2005). The Algorithm used to compute the exact finite sample risk is introduced and explained in Kohl (2005). It is based on FFT.

References

Huber, P.J. (1968) Robust Confidence Limits. Z. Wahrscheinlichkeitstheor. Verw. Geb. 10:269--278.

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106-115.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

FixRobModel-class