Learn R Programming

ROptEst (version 1.0)

getInfClip: Generic Function for the Computation of the Optimal Clipping Bound

Description

Generic function for the computation of the optimal clipping bound in case of infinitesimal robust models. This function is rarely called directly. It is used to compute optimally robust ICs.

Usage

getInfClip(clip, L2deriv, risk, neighbor, ...)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, Distr, stand, cent, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfClip"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)

Arguments

clip
positive real: clipping bound
L2deriv
L2-derivative of some L2-differentiable family of probability measures.
risk
object of class "RiskType".
neighbor
object of class "Neighborhood".
...
additional parameters.
biastype
object of class "BiasType"
cent
optimal centering constant.
stand
standardizing matrix.
Distr
object of class "Distribution".
symm
logical: indicating symmetry of L2deriv.
trafo
matrix: transformation of the parameter.

Value

Methods

References

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115.

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22, 201-223.

Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

ContIC-class, TotalVarIC-class