Learn R Programming

ROptEst (version 1.0)

getInfGamma: Generic Function for the Computation of the Optimal Clipping Bound

Description

Generic function for the computation of the optimal clipping bound. This function is rarely called directly. It is called by getInfClip to compute optimally robust ICs.

Usage

getInfGamma(L2deriv, risk, neighbor, biastype, ...)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, Distr, stand, cent, clip, power = 1L)
"getInfGamma"(L2deriv, risk, neighbor, biastype, Distr, stand, cent, clip, power = 1L)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)

Arguments

L2deriv
L2-derivative of some L2-differentiable family of probability measures.
risk
object of class "RiskType".
neighbor
object of class "Neighborhood".
biastype
object of class "BiasType"
...
additional parameters
cent
optimal centering constant.
clip
optimal clipping bound.
stand
standardizing matrix.
Distr
object of class "Distribution".
power
exponent for the integrand; by default 1, but may also be 2, for optimization in getLagrangeMultByOptim.

Methods

Details

The function is used in case of asymptotic G-risks; confer Ruckdeschel and Rieder (2004).

References

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115.

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22, 201-223. Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

asGRisk-class, asMSE-class, asUnOvShoot-class, ContIC-class, TotalVarIC-class