Learn R Programming

ROptEst (version 1.0)

getInfRad: Generic Function for the Computation of the Optimal Radius for Given Clipping Bound

Description

The usual robust optimality problem for given asGRisk searches the optimal clipping height b of a Hampel-type IC to given radius of the neighborhood. Instead, again for given asGRisk and for given Hampel-Type IC with given clipping height b we may determine the radius of the neighborhood for which it is optimal in the sense of the first sentence. This radius is determined by getInfRad. This function is rarely called directly. It is used withing getRadius.

Usage

getInfRad(clip, L2deriv, risk, neighbor, ...)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, Distr, stand, cent, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)
"getInfRad"( clip, L2deriv, risk, neighbor, biastype, cent, symm, trafo)

Arguments

clip
positive real: clipping bound
L2deriv
L2-derivative of some L2-differentiable family of probability measures.
risk
object of class "RiskType".
neighbor
object of class "Neighborhood".
...
additional parameters.
biastype
object of class "BiasType"
cent
optimal centering constant.
stand
standardizing matrix.
Distr
object of class "Distribution".
symm
logical: indicating symmetry of L2deriv.
trafo
matrix: transformation of the parameter.

Value

Methods

References

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115.

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22, 201-223.

Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

ContIC-class, TotalVarIC-class