Learn R Programming

ROptEst (version 1.0)

getInfRobIC: Generic Function for the Computation of Optimally Robust ICs

Description

Generic function for the computation of optimally robust ICs in case of infinitesimal robust models. This function is rarely called directly.

Usage

getInfRobIC(L2deriv, risk, neighbor, ...)
"getInfRobIC"(L2deriv, risk, neighbor, Finfo, trafo, verbose = NULL)
"getInfRobIC"(L2deriv, risk, neighbor, Finfo, trafo, verbose = NULL)
"getInfRobIC"(L2deriv, risk, neighbor, Distr, Finfo, trafo, QuadForm = diag(nrow(trafo)), verbose = NULL)
"getInfRobIC"(L2deriv, risk, neighbor, symm, trafo, maxiter, tol, warn, Finfo, verbose = NULL, ...)
"getInfRobIC"(L2deriv, risk, neighbor, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, z.start, A.start, Finfo, trafo, maxiter, tol, warn, verbose = NULL, ...)
"getInfRobIC"(L2deriv, risk, neighbor, symm, Finfo, trafo, upper = NULL, lower=NULL, maxiter, tol, warn, noLow = FALSE, verbose = NULL, checkBounds = TRUE, ...)
"getInfRobIC"(L2deriv, risk, neighbor, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, Finfo, trafo, onesetLM = FALSE, z.start, A.start, upper = NULL, lower=NULL, OptOrIter = "iterate", maxiter, tol, warn, verbose = NULL, checkBounds = TRUE, ..., .withEvalAsVar = TRUE)
"getInfRobIC"( L2deriv, risk, neighbor, symm, Finfo, trafo, upper = NULL, lower=NULL, maxiter, tol, warn, noLow = FALSE, verbose = NULL, checkBounds = TRUE, ...)
"getInfRobIC"(L2deriv, risk, neighbor, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, Finfo, trafo, onesetLM = FALSE, z.start, A.start, upper = NULL, lower=NULL, OptOrIter = "iterate", maxiter, tol, warn, verbose = NULL, checkBounds = TRUE, ...)
"getInfRobIC"(L2deriv, risk, neighbor, symm, Finfo, trafo, upper = NULL, lower = NULL, maxiter, tol, warn, noLow = FALSE, verbose = NULL, ...)
"getInfRobIC"(L2deriv, risk, neighbor, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, Finfo, trafo, onesetLM = FALSE, z.start, A.start, upper = NULL, lower = NULL, OptOrIter = "iterate", maxiter, tol, warn, verbose = NULL, withPICcheck = TRUE, ..., .withEvalAsVar = TRUE)
"getInfRobIC"( L2deriv, risk, neighbor, symm, Finfo, trafo, upper, lower, maxiter, tol, warn, ...)

Arguments

L2deriv
L2-derivative of some L2-differentiable family of probability measures.
risk
object of class "RiskType".
neighbor
object of class "Neighborhood".
...
additional parameters (mainly for optim).
Distr
object of class "Distribution".
symm
logical: indicating symmetry of L2deriv.
DistrSymm
object of class "DistributionSymmetry".
L2derivSymm
object of class "FunSymmList".
L2derivDistrSymm
object of class "DistrSymmList".
Finfo
Fisher information matrix.
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
trafo
matrix: transformation of the parameter.
upper
upper bound for the optimal clipping bound.
lower
lower bound for the optimal clipping bound.
OptOrIter
character; which method to be used for determining Lagrange multipliers A and a: if (partially) matched to "optimize", getLagrangeMultByOptim is used; otherwise: by default, or if matched to "iterate" or to "doubleiterate", getLagrangeMultByIter is used. More specifically, when using getLagrangeMultByIter, and if argument risk is of class "asGRisk", by default and if matched to "iterate" we use only one (inner) iteration, if matched to "doubleiterate" we use up to Maxiter (inner) iterations.
maxiter
the maximum number of iterations.
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.
noLow
logical: is lower case to be computed?
onesetLM
logical: use one set of Lagrange multipliers?
QuadForm
matrix of (or which may coerced to) class PosSemDefSymmMatrix for use of different (standardizing) norm
verbose
logical: if TRUE, some messages are printed
checkBounds
logical: if TRUE, minimal and maximal clipping bound are computed to check if a valid bound was specified.
withPICcheck
logical: at the end of the algorithm, shall we check how accurately this is a pIC; this will only be done if withPICcheck && verbose.
.withEvalAsVar
logical (of length 1): if TRUE, risks based on covariances are to be evaluated (default), otherwise just a call is returned.

Value

Methods

References

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106-115.

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22: 201-223.

Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

InfRobModel-class