Learn R Programming

ROptEst (version 1.0)

getInfStand: Generic Function for the Computation of the Standardizing Matrix

Description

Generic function for the computation of the standardizing matrix which takes care of the Fisher consistency of the corresponding IC. This function is rarely called directly. It is used to compute optimally robust ICs.

Usage

getInfStand(L2deriv, neighbor, biastype, ...)
"getInfStand"(L2deriv, neighbor, biastype, clip, cent, trafo)
"getInfStand"(L2deriv, neighbor, biastype, clip, cent, trafo)
"getInfStand"(L2deriv, neighbor, biastype, Distr, A.comp, cent, trafo, w)
"getInfStand"(L2deriv, neighbor, biastype, clip, cent, trafo)
"getInfStand"(L2deriv, neighbor, biastype, clip, cent, trafo)

Arguments

L2deriv
L2-derivative of some L2-differentiable family of probability measures.
neighbor
object of class "Neighborhood"
biastype
object of class "BiasType"
...
additional parameters
clip
optimal clipping bound.
cent
optimal centering constant.
Distr
object of class "Distribution".
trafo
matrix: transformation of the parameter.
A.comp
matrix: indication which components of the standardizing matrix have to be computed.
w
object of class RobWeight; current weight

Value

Methods

References

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

ContIC-class, TotalVarIC-class