Learn R Programming

ROptEst (version 1.0)

getModifyIC: Generic Function for the Computation of Functions for Slot modifyIC

Description

These function is used by internal computations and is rarely called directly.

Usage

getModifyIC(L2FamIC, neighbor, risk,...) "getModifyIC"(L2FamIC, neighbor, risk, ...) "getModifyIC"(L2FamIC, neighbor, risk, ...) "getModifyIC"(L2FamIC, neighbor, risk, ...) "getModifyIC"(L2FamIC, neighbor, risk, ...) "getModifyIC"(L2FamIC, neighbor, risk, ...)
scaleUpdateIC(neighbor,...) "scaleUpdateIC"(neighbor, sdneu, sdalt, IC) "scaleUpdateIC"(neighbor, sdneu, sdalt, IC) "scaleUpdateIC"(neighbor, sdneu, sdalt, IC)

Arguments

L2FamIC
object of class L2ParamFamily.
neighbor
object of class "Neighborhood".
risk
object of class "RiskType"
...
further arguments to be passed over to optIC.
sdneu
positive numeric of length one; the new scale.
sdalt
positive numeric of length one; the new scale.
IC
a Hampel-IC to be updated.

Value

Details

This function is used for internal computations. By setting RobAStBaseOption("all.verbose" = TRUE) somewhere globally, the generated function modifyIC will generate calls to optIC with argument verbose=TRUE.

References

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

optIC, IC-class