Learn R Programming

ROptEst (version 1.0)

getRiskIC: Generic function for the computation of a risk for an IC

Description

Generic function for the computation of a risk for an IC.

Usage

getRiskIC(IC, risk, neighbor, L2Fam, ...)
"getRiskIC"(IC, risk)
"getRiskIC"(IC, risk, L2Fam) "getRiskIC"(IC, risk, L2Fam)

Arguments

IC
object of class "InfluenceCurve"
risk
object of class "RiskType".
neighbor
object of class "Neighborhood"; missing in the methods described here.
...
additional parameters
L2Fam
object of class "L2ParamFamily".

Value

Methods

Details

To make sure that the results are valid, it is recommended to include an additional check of the IC properties of IC using checkIC.

References

Huber, P.J. (1968) Robust Confidence Limits. Z. Wahrscheinlichkeitstheor. Verw. Geb. 10:269--278.

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115.

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

Ruckdeschel, P. and Kohl, M. (2005) Computation of the Finite Sample Risk of M-estimators on Neighborhoods.

See Also

getRiskIC, InfRobModel-class

Examples

Run this code
B <- BinomFamily(size = 25, prob = 0.25)

## classical optimal IC
IC0 <- optIC(model = B, risk = asCov())
getRiskIC(IC0, asCov())

Run the code above in your browser using DataLab