Learn R Programming

ROptEst (version 0.5.0)

leastFavorableRadius: Generic Function for the Computation of Least Favorable Radii

Description

Generic function for the computation of least favorable radii.

Usage

leastFavorableRadius(L2Fam, neighbor, risk, ...)

## S3 method for class 'L2ParamFamily,UncondNeighborhood,asGRisk':
leastFavorableRadius(L2Fam, neighbor, risk, rho, upRad = 1, 
            z.start = NULL, A.start = NULL, upper = 100, maxiter = 100, 
            tol = .Machine$double.eps^0.4, warn = FALSE)

Arguments

L2Fam
L2-differentiable family of probability measures.
neighbor
object of class "Neighborhood".
risk
object of class "RiskType".
...
additional parameters
upRad
the upper end point of the radius interval to be searched.
rho
The considered radius interval is: $[r \rho, r/\rho]$ with $\rho\in(0,1)$.
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
upper
upper bound for the optimal clipping bound.
maxiter
the maximum number of iterations
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.

Value

  • The least favorable radius and the corresponding inefficiency are computed.

concept

least favorable radius

References

Rieder, H., Kohl, M. and Ruckdeschel, P. (2001) The Costs of not Knowing the Radius. Submitted. Appeared as discussion paper Nr. 81. SFB 373 (Quantification and Simulation of Economic Processes), Humboldt University, Berlin; also available under www.uni-bayreuth.de/departments/math/org/mathe7/RIEDER/pubs/RR.pdf Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

radiusMinimaxIC

Examples

Run this code
N <- NormLocationFamily(mean=0, sd=1) 
leastFavorableRadius(L2Fam=N, neighbor=ContNeighborhood(),
                     risk=asMSE(), rho=0.5)

Run the code above in your browser using DataLab