Learn R Programming

ROptEst (version 0.5.0)

locMEstimator: Generic function for the computation of location M estimators

Description

Generic function for the computation of location M estimators.

Usage

locMEstimator(x, IC, ...)

## S3 method for class 'numeric,InfluenceCurve':
locMEstimator(x, IC, eps = .Machine$double.eps^0.5)

Arguments

x
sample
IC
object of class "InfluenceCurve"
...
additional parameters
eps
the desired accuracy (convergence tolerance).

Value

  • Returns a list with component
  • locM estimator of location

concept

  • M estimator
  • estimator

References

Huber, P.J. (1964) Robust estimation of a location parameter. Ann. Math. Stat. 35: 73--101. Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer. Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

InfluenceCurve-class