Learn R Programming

ROptEst (version 1.0)

optIC: Generic function for the computation of optimally robust ICs

Description

Generic function for the computation of optimally robust ICs.

Usage

optIC(model, risk, ...)
"optIC"(model, risk, z.start = NULL, A.start = NULL, upper = 1e4, lower = 1e-4, OptOrIter = "iterate", maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, noLow = FALSE, verbose = NULL, ..., .withEvalAsVar = TRUE, returnNAifProblem = FALSE)
"optIC"(model, risk, upper = 1e4, lower = 1e-4, maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, verbose = NULL)
"optIC"(model, risk, sampleSize, upper = 1e4, lower = 1e-4, maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, Algo = "A", cont = "left", verbose = NULL)

Arguments

model
probability model.
risk
object of class "RiskType".
...
additional parameters.
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
upper
upper bound for the optimal clipping bound.
lower
lower bound for the optimal clipping bound.
maxiter
the maximum number of iterations.
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.
sampleSize
integer: sample size.
Algo
"A" or "B".
cont
"left" or "right".
noLow
logical: is lower case to be computed?
OptOrIter
character; which method to be used for determining Lagrange multipliers A and a: if (partially) matched to "optimize", getLagrangeMultByOptim is used; otherwise: by default, or if matched to "iterate" or to "doubleiterate", getLagrangeMultByIter is used. More specifically, when using getLagrangeMultByIter, and if argument risk is of class "asGRisk", by default and if matched to "iterate" we use only one (inner) iteration, if matched to "doubleiterate" we use up to Maxiter (inner) iterations.
verbose
logical: if TRUE, some messages are printed.
.withEvalAsVar
logical (of length 1): if TRUE, risks based on covariances are to be evaluated (default), otherwise just a call is returned.
returnNAifProblem
logical (of length 1): if TRUE (not the default), in case of convergence problems in the algorithm, returns NA.

Value

Methods

Details

In case of the finite-sample risk "fiUnOvShoot" one can choose between two algorithms for the computation of this risk where the least favorable contamination is assumed to be left or right of some bound. For more details we refer to Section 11.3 of Kohl (2005).

References

Huber, P.J. (1968) Robust Confidence Limits. Z. Wahrscheinlichkeitstheor. Verw. Geb. 10:269--278.

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

Kohl, M. and Ruckdeschel, P. (2010): R package distrMod: Object-Oriented Implementation of Probability Models. J. Statist. Softw. 35(10), 1--27 Kohl, M. and Ruckdeschel, P., and Rieder, H. (2010): Infinitesimally Robust Estimation in General Smoothly Parametrized Models. Stat. Methods Appl., 19, 333--354. Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115.

Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.

Rieder, H., Kohl, M. and Ruckdeschel, P. (2008) The Costs of not Knowing the Radius. Statistical Methods and Applications 17(1) 13-40.

Rieder, H., Kohl, M. and Ruckdeschel, P. (2001) The Costs of not Knowing the Radius. Appeared as discussion paper Nr. 81. SFB 373 (Quantification and Simulation of Economic Processes), Humboldt University, Berlin; also available under www.uni-bayreuth.de/departments/math/org/mathe7/RIEDER/pubs/RR.pdf

See Also

InfluenceCurve-class, RiskType-class

Examples

Run this code
B <- BinomFamily(size = 25, prob = 0.25) 

## classical optimal IC
IC0 <- optIC(model = B, risk = asCov())
plot(IC0) # plot IC
checkIC(IC0, B)

Run the code above in your browser using DataLab