Learn R Programming

ROptEst (version 1.0)

radiusMinimaxIC: Generic function for the computation of the radius minimax IC

Description

Generic function for the computation of the radius minimax IC.

Usage

radiusMinimaxIC(L2Fam, neighbor, risk, ...)
"radiusMinimaxIC"( L2Fam, neighbor, risk, loRad = 0, upRad = Inf, z.start = NULL, A.start = NULL, upper = NULL, lower = NULL, OptOrIter = "iterate", maxiter = 50, tol = .Machine$double.eps^0.4, warn = FALSE, verbose = NULL, loRad0 = 1e-3, ..., returnNAifProblem = FALSE, loRad.s = NULL, upRad.s = NULL)

Arguments

L2Fam
L2-differentiable family of probability measures.
neighbor
object of class "Neighborhood".
risk
object of class "RiskType".
loRad
the lower end point of the interval to be searched in the inner optimization (for the least favorable situation to the user-guessed radius).
upRad
the upper end point of the interval to be searched in the inner optimization (for the least favorable situation to the user-guessed radius).
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
upper
upper bound for the optimal clipping bound.
lower
lower bound for the optimal clipping bound.
OptOrIter
character; which method to be used for determining Lagrange multipliers A and a: if (partially) matched to "optimize", getLagrangeMultByOptim is used; otherwise: by default, or if matched to "iterate" or to "doubleiterate", getLagrangeMultByIter is used. More specifically, when using getLagrangeMultByIter, and if argument risk is of class "asGRisk", by default and if matched to "iterate" we use only one (inner) iteration, if matched to "doubleiterate" we use up to Maxiter (inner) iterations.
maxiter
the maximum number of iterations
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.
verbose
logical: if TRUE, some messages are printed
loRad0
for numerical reasons: the effective lower bound for the zero search; internally set to max(loRad,loRad0).
...
further arguments to be passed on to getInfRobIC
returnNAifProblem
logical (of length 1): if TRUE (not the default), in case of convergence problems in the algorithm, returns NA.
loRad.s
the lower end point of the interval to be searched in the outer optimization (for the user-guessed radius); if NULL (default) set to loRad in the algorithm.
upRad.s
the upper end point of the interval to be searched in the outer optimization (for the user-guessed radius); if NULL (default) set to upRad in the algorithm.

Value

Methods

Details

In case the neighborhood radius is unknown, Rieder et al. (2001, 2008) and Kohl (2005) show that there is nevertheless a way to compute an optimally robust IC - the so-called radius-minimax IC - which is optimal for some radius interval.

References

Rieder, H., Kohl, M. and Ruckdeschel, P. (2008) The Costs of not Knowing the Radius. Statistical Methods and Applications, 17(1) 13-40.

Rieder, H., Kohl, M. and Ruckdeschel, P. (2001) The Costs of not Knowing the Radius. Appeared as discussion paper Nr. 81. SFB 373 (Quantification and Simulation of Economic Processes), Humboldt University, Berlin; also available under www.uni-bayreuth.de/departments/math/org/mathe7/RIEDER/pubs/RR.pdf

Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

radiusMinimaxIC

Examples

Run this code
N <- NormLocationFamily(mean=0, sd=1) 
radIC <- radiusMinimaxIC(L2Fam=N, neighbor=ContNeighborhood(), 
                         risk=asMSE(), loRad=0.1, upRad=0.5)
checkIC(radIC)

Run the code above in your browser using DataLab