getAsRisk(risk, L2deriv, neighbor, biastype, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand, trafo, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, trafo, ...)
"getAsRisk"( risk,L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, Finfo, trafo, z.start, A.start, maxiter, tol, warn, verbose = NULL, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent = NULL, stand = NULL, Distr, DistrSymm, L2derivSymm, L2derivDistrSymm, Finfo, trafo, z.start, A.start, maxiter, tol, warn, verbose = NULL, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype = NULL, clip = NULL, cent, stand, Distr, trafo = NULL, V.comp = matrix(TRUE, ncol = nrow(stand), nrow = nrow(stand)), w, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype, clip, cent, stand, Distr, trafo = NULL, V.comp = matrix(TRUE, ncol = nrow(stand), nrow = nrow(stand)), w, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo = NULL, FI, ...)
"getAsRisk"(risk, L2deriv, neighbor, biastype, normtype, clip, cent, stand, Distr, trafo = NULL, V.comp = matrix(TRUE, ncol = nrow(stand), nrow = nrow(stand)), FI, w, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo, ...)
"getAsRisk"( risk, L2deriv, neighbor, biastype, normtype = NULL, clip, cent, stand, trafo, ...)"asRisk". "Neighborhood". "ANY". "Distribution". "DistributionSymmetry". "FunSymmList". "DistrSymmList". "NormType". RobWeight; current weightTRUE some diagnostics are printed out.Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22, 201-223.
Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.
Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.
asRisk-class