getIneffDiff(radius, L2Fam, neighbor, risk, ...)
"getIneffDiff"( radius, L2Fam, neighbor, risk, loRad, upRad, loRisk, upRisk, z.start = NULL, A.start = NULL, upper.b = NULL, lower.b = NULL, OptOrIter = "iterate", MaxIter, eps, warn, loNorm = NULL, upNorm = NULL, verbose = NULL, ..., withRetIneff = FALSE)"Neighborhood". "RiskType". A and a: if (partially) matched to "optimize",
getLagrangeMultByOptim is used; otherwise: by default, or if matched to
"iterate" or to "doubleiterate",
getLagrangeMultByIter is used. More specifically,
when using getLagrangeMultByIter, and if argument risk is of
class "asGRisk", by default and if matched to "iterate"
we use only one (inner) iteration, if matched to "doubleiterate"
we use up to Maxiter (inner) iterations."NormType"; used in selfstandardization
to evaluate the bias of the current IC in the norm of the lower
bound"NormType"; used in selfstandardization
to evaluate the bias of the current IC in the norm of the upper
boundTRUE, some messages are printed getInfRobICTRUE, getIneffDiff returns the
vector of lower and upper inefficiency (components named "lo" and "up"),
otherwise (default) the difference.
The latter was used in radiusMinimaxIC up to version 0.8
for a call to uniroot directly. In order to speed up things
(i.e., not to call the expensive getInfRobIC once again at the zero,
up to version 0.8 we had some awkward assign-sys.frame
construction to modify the caller writing the upper inefficiency already
computed to the caller environment; having capsulated this into try
from version 0.9 on, this became even more awkward, so from version 0.9
onwards, we instead use the TRUE-alternative when calling it
from radiusMinimaxIC.Rieder, H., Kohl, M. and Ruckdeschel, P. (2001) The Costs of not Knowing the Radius. Submitted. Appeared as discussion paper Nr. 81. SFB 373 (Quantification and Simulation of Economic Processes), Humboldt University, Berlin; also available under www.uni-bayreuth.de/departments/math/org/mathe7/RIEDER/pubs/RR.pdf
Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.
radiusMinimaxIC, leastFavorableRadius