Usage
getIneffDiff(radius, L2Fam, neighbor, risk, ...)
## S3 method for class 'numeric,L2ParamFamily,UncondNeighborhood,asMSE':
getIneffDiff(radius, L2Fam, neighbor, risk, loRad, upRad,
loRisk, upRisk, z.start = NULL, A.start = NULL, upper.b, MaxIter, eps, warn)Arguments
radius
neighborhood radius.
L2Fam
L2-differentiable family of probability measures.
neighbor
object of class "Neighborhood".
risk
object of class "RiskType".
loRad
the lower end point of the interval to be searched.
upRad
the upper end point of the interval to be searched.
loRisk
the risk at the lower end point of the interval.
upRisk
the risk at the upper end point of the interval.
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
upper.b
upper bound for the optimal clipping bound.
MaxIter
the maximum number of iterations
eps
the desired accuracy (convergence tolerance).
warn
logical: print warnings.