Learn R Programming

ROptEst (version 0.5.0)

getInfClip: Generic Function for the Computation of the Optimal Clipping Bound

Description

Generic function for the computation of the optimal clipping bound in case of infinitesimal robust models. This function is rarely called directly. It is used to compute optimally robust ICs.

Usage

getInfClip(clip, L2deriv, risk, neighbor, ...)

## S3 method for class 'numeric,UnivariateDistribution,asMSE,ContNeighborhood':
getInfClip(clip, L2deriv, risk, neighbor, cent, symm, trafo)

## S3 method for class 'numeric,UnivariateDistribution,asMSE,TotalVarNeighborhood':
getInfClip(clip, L2deriv, risk, neighbor, cent, symm, trafo)

## S3 method for class 'numeric,EuclRandVariable,asMSE,ContNeighborhood':
getInfClip(clip, L2deriv, risk, neighbor, Distr, stand, cent, trafo)

## S3 method for class 'numeric,UnivariateDistribution,asUnOvShoot,UncondNeighborhood':
getInfClip(clip, L2deriv, risk, neighbor, cent, symm, trafo)

Arguments

clip
positive real: clipping bound
L2deriv
L2-derivative of some L2-differentiable family of probability measures.
risk
object of class "RiskType".
neighbor
object of class "Neighborhood".
...
additional parameters.
cent
optimal centering constant.
stand
standardizing matrix.
Distr
object of class "Distribution".
symm
logical: indicating symmetry of L2deriv.
trafo
matrix: transformation of the parameter.

Value

  • The optimal clipping bound is computed.

concept

influence curve

References

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115. Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer. Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

ContIC-class, TotalVarIC-class