getInfClip
to compute optimally robust ICs.
getInfGamma(L2deriv, risk, neighbor, biastype, ...)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, Distr, stand, cent, clip, power = 1L)
"getInfGamma"(L2deriv, risk, neighbor, biastype, Distr, stand, cent, clip, power = 1L)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)
"getInfGamma"(L2deriv, risk, neighbor, biastype, cent, clip)"RiskType". "Neighborhood". "BiasType" "Distribution". 1, but
may also be 2, for optimization in getLagrangeMultByOptim. Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.
Ruckdeschel, P. and Rieder, H. (2004) Optimal Influence Curves for General Loss Functions. Statistics & Decisions 22, 201-223. Ruckdeschel, P. (2005) Optimally One-Sided Bounded Influence Curves. Mathematical Methods in Statistics 14(1), 105-131.
Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.
asGRisk-class, asMSE-class,
asUnOvShoot-class, ContIC-class,
TotalVarIC-class