Learn R Programming

ROptEst (version 0.5.0)

getInfRobIC: Generic Function for the Computation of Optimally Robust ICs

Description

Generic function for the computation of optimally robust ICs in case of infinitesimal robust models. This function is rarely called directly.

Usage

getInfRobIC(L2deriv, risk, neighbor, ...)

## S3 method for class 'UnivariateDistribution,asCov,ContNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, Finfo, trafo)

## S3 method for class 'UnivariateDistribution,asCov,TotalVarNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, Finfo, trafo)

## S3 method for class 'RealRandVariable,asCov,ContNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, Distr, Finfo, trafo)

## S3 method for class 'UnivariateDistribution,asBias,ContNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, symm, Finfo, trafo, 
             upper, maxiter, tol, warn)

## S3 method for class 'UnivariateDistribution,asBias,TotalVarNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, symm, Finfo, trafo, 
             upper, maxiter, tol, warn)

## S3 method for class 'RealRandVariable,asBias,ContNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, Distr, DistrSymm, L2derivSymm, 
             L2derivDistrSymm, Finfo, z.start, A.start, trafo, upper, maxiter, tol, warn)

## S3 method for class 'UnivariateDistribution,asHampel,UncondNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, symm, Finfo, trafo, 
             upper, maxiter, tol, warn)

## S3 method for class 'RealRandVariable,asHampel,ContNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, Distr, DistrSymm, L2derivSymm, 
             L2derivDistrSymm, Finfo, z.start, A.start, trafo, upper, maxiter, tol, warn)

## S3 method for class 'UnivariateDistribution,asGRisk,UncondNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, symm, Finfo, trafo, 
             upper, maxiter, tol, warn)

## S3 method for class 'RealRandVariable,asGRisk,ContNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, Distr, DistrSymm, L2derivSymm, 
             L2derivDistrSymm, Finfo, z.start, A.start, trafo, upper, maxiter, tol, warn)

## S3 method for class 'UnivariateDistribution,asUnOvShoot,UncondNeighborhood':
getInfRobIC(L2deriv, risk, neighbor, symm, Finfo, trafo, 
             upper, maxiter, tol, warn)

Arguments

L2deriv
L2-derivative of some L2-differentiable family of probability measures.
risk
object of class "RiskType".
neighbor
object of class "Neighborhood".
...
additional parameters.
Distr
object of class "Distribution".
symm
logical: indicating symmetry of L2deriv.
DistrSymm
object of class "DistributionSymmetry".
L2derivSymm
object of class "FunSymmList".
L2derivDistrSymm
object of class "DistrSymmList".
Finfo
Fisher information matrix.
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
trafo
matrix: transformation of the parameter.
upper
upper bound for the optimal clipping bound.
maxiter
the maximum number of iterations.
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.

Value

  • The optimally robust IC is computed.

concept

influence curve

References

Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115. Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer. Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

InfRobModel-class