.RMXE.th(th, PFam, modifyfct, loRad = 0, upRad = Inf, z.start = NULL, A.start = NULL, upper = NULL, lower = NULL, OptOrIter = "iterate", maxiter = 50, tol = .Machine$double.eps^0.4, loRad0 = 1e-3, ...)
.MBRE.th(th, PFam, modifyfct, z.start = NULL, A.start = NULL, upper = 1e4, lower = 1e-4, OptOrIter = "iterate", maxiter = 50, tol = .Machine$double.eps^0.4, ...)
.OMSE.th(th, PFam, modifyfct, radius = 0.5, z.start = NULL, A.start = NULL, upper = 1e4, lower = 1e-4, OptOrIter = "iterate", maxiter = 50, tol = .Machine$double.eps^0.4, ...)
.getLMGrid(thGrid, PFam, optFct = .RMXE.th, modifyfct, radius = 0.5, GridFileName = "LMGrid.Rdata", withPrint = FALSE, upper = 1e4, lower = 1e-4, OptOrIter = "iterate", maxiter = 50, tol = .Machine$double.eps^0.4, loRad = 0, upRad = Inf, loRad0 = 1e-3, loRad.s = 0.2, up.Rad.s = 1, withStartLM = TRUE, len = 13)
.saveGridToCSV(Grid, toFileCSV, namPFam, nameInSysdata)
.readGridFromCSV <- function(fromFileCSV)
.generateInterpGrid(thGrid, PFam, toFileCSV = "temp.csv", getFun = .getLMGrid, ..., modifyfct, nameInSysdata, GridFileName, withPrint = TRUE, len = 13)"ParamFamily", the parametric family
at which to evaluate the Lagrange multipliers or LDEstimators;
in our use case, it is a shape-scale model, hence the respective
(main) parameter must contain "scale" and "shape". th and PFam to move
the parametric family to the point of the grid value; returns the
moved parametric family.NULL
set to loRad in the algorithm. NULL set to upRad in the algorithm. A and a: if (partially) matched to "optimize",
getLagrangeMultByOptim is used; otherwise: by default, or if matched to
"iterate" or to "doubleiterate",
getLagrangeMultByIter is used. More specifically,
when using getLagrangeMultByIter, and if argument risk is of
class "asGRisk", by default and if matched to "iterate"
we use only one (inner) iteration, if matched to "doubleiterate"
we use up to Maxiter (inner) iterations. max(loRad,loRad0). theta, PFam,
and modifyfct; determines the Lagrange multipliers. GridFileName!="", the pure
y-grid values are saved under this filename. th, second argument
PFam and last arguments GridFileName,
withPrint; produces the y-values for the
interpolation grid. getFun. .saveGridToCSVinvisible(NULL)..readGridFromCSV a list with the read-in items, i.e.,
an item Grid with the grid, an item namPFam with the name of
the parametric family, and namInSysdata, the name of the read in grid..generateInterpGridinvisible(NULL).
.MBRE.th computes the Lagrange multipliers for the MBRE estimator,
.OMSE.th for the OMSE estimator at radius radius,
and .RMXE.th the RMXE estimator. .getLMGrid in a large loop computes the Lagrange multipliers for
optimally robust IFs for each element of a given grid.
.saveGridToCSV saves a given grid to a csv file, and in addition,
in a file with same name but with file extension ".txt" writes the
parametric family and the grid name.
.readGridFromCSV reads in a grid from a csv file together with the
information given in the corresponding ".txt" file.
.generateInterpGrid by means of calls to function-argument getFun
(e.g. getLMGrid computes the grid, if desired smoothes it, and
then saves it to .csv.