Rdocumentation
powered by
Learn R Programming
ROptEst (version 1.0)
internals_for_MBRE_computation: Internal / Helper function of package ROptEst for MBRE calculation
Description
This function computes the coordinatewise min and max of an IC numerically.
Usage
.getExtremeCoordIC(IC, D, indi, n = 10000)
Arguments
IC
object of class
IC
D
a univariate distribution; by means of
q(D)
, we determine the evaluation grid.
indi
integer; the indices of the coordinates at which to compute min and max.
n
integer; number of grid points for evaluation.
Value
length(indi)
rows and 2 columns
min
and
max
: the coordinate-wise min and max of the IC.