optIC(model, risk, ...)
"optIC"(model, risk, z.start = NULL, A.start = NULL, upper = 1e4, lower = 1e-4, OptOrIter = "iterate", maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, noLow = FALSE, verbose = NULL, ..., .withEvalAsVar = TRUE, returnNAifProblem = FALSE)
"optIC"(model, risk, upper = 1e4, lower = 1e-4, maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, verbose = NULL)
"optIC"(model, risk, sampleSize, upper = 1e4, lower = 1e-4, maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, Algo = "A", cont = "left", verbose = NULL)"RiskType". A and a: if (partially) matched to "optimize",
getLagrangeMultByOptim is used; otherwise: by default, or if matched to
"iterate" or to "doubleiterate",
getLagrangeMultByIter is used. More specifically,
when using getLagrangeMultByIter, and if argument risk is of
class "asGRisk", by default and if matched to "iterate"
we use only one (inner) iteration, if matched to "doubleiterate"
we use up to Maxiter (inner) iterations. TRUE, some messages are printed. TRUE, risks based on covariances are to be
evaluated (default), otherwise just a call is returned. TRUE (not the default), in case of convergence problems in
the algorithm, returns NA. "fiUnOvShoot" one can choose
between two algorithms for the computation of this risk where the least favorable
contamination is assumed to be left or right of some bound. For more details
we refer to Section 11.3 of Kohl (2005).Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.
Kohl, M. and Ruckdeschel, P. (2010): R package distrMod: Object-Oriented Implementation of Probability Models. J. Statist. Softw. 35(10), 1--27 Kohl, M. and Ruckdeschel, P., and Rieder, H. (2010): Infinitesimally Robust Estimation in General Smoothly Parametrized Models. Stat. Methods Appl., 19, 333--354. Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115.
Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.
Rieder, H., Kohl, M. and Ruckdeschel, P. (2008) The Costs of not Knowing the Radius. Statistical Methods and Applications 17(1) 13-40.
Rieder, H., Kohl, M. and Ruckdeschel, P. (2001) The Costs of not Knowing the Radius. Appeared as discussion paper Nr. 81. SFB 373 (Quantification and Simulation of Economic Processes), Humboldt University, Berlin; also available under www.uni-bayreuth.de/departments/math/org/mathe7/RIEDER/pubs/RR.pdf
InfluenceCurve-class, RiskType-classB <- BinomFamily(size = 25, prob = 0.25)
## classical optimal IC
IC0 <- optIC(model = B, risk = asCov())
plot(IC0) # plot IC
checkIC(IC0, B)
Run the code above in your browser using DataLab