Learn R Programming

ROptEst (version 0.5.0)

optIC: Generic function for the computation of optimally robust ICs

Description

Generic function for the computation of optimally robust ICs.

Usage

optIC(model, risk, ...)

## S3 method for class 'L2ParamFamily,asCov':
optIC(model, risk)

## S3 method for class 'InfRobModel,asRisk':
optIC(model, risk, z.start = NULL, A.start = NULL, upper = 1e4, 
             maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE)

## S3 method for class 'InfRobModel,asUnOvShoot':
optIC(model, risk, upper = 1e4, maxiter = 50, 
             tol = .Machine$double.eps^0.4, warn = TRUE)

## S3 method for class 'FixRobModel,fiUnOvShoot':
optIC(model, risk, sampleSize, upper = 1e4, maxiter = 50, 
             tol = .Machine$double.eps^0.4, warn = TRUE, Algo = "A", cont = "left")

Arguments

model
probability model.
risk
object of class "RiskType".
...
additional parameters.
z.start
initial value for the centering constant.
A.start
initial value for the standardizing matrix.
upper
upper bound for the optimal clipping bound.
maxiter
the maximum number of iterations.
tol
the desired accuracy (convergence tolerance).
warn
logical: print warnings.
sampleSize
integer: sample size.
Algo
"A" or "B".
cont
"left" or "right".

Value

  • Some optimally robust IC is computed.

concept

  • robust influence curve
  • influence curve

Details

In case of the finite-sample risk "fiUnOvShoot" one can choose between two algorithms for the computation of this risk where the least favorable contamination is assumed to be left or right of some bound. For more details we refer to Section 11.3 of Kohl (2005).

References

Huber, P.J. (1968) Robust Confidence Limits. Z. Wahrscheinlichkeitstheor. Verw. Geb. 10:269--278. Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115. Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer. Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.

See Also

InfluenceCurve-class, RiskType-class

Examples

Run this code
B <- BinomFamily(size = 25, prob = 0.25) 

## classical optimal IC
IC0 <- optIC(model = B, risk = asCov())
plot(IC0) # plot IC
checkIC(IC0, B)

Run the code above in your browser using DataLab