optIC(model, risk, ...)
## S3 method for class 'L2ParamFamily,asCov':
optIC(model, risk)
## S3 method for class 'InfRobModel,asRisk':
optIC(model, risk, z.start = NULL, A.start = NULL, upper = 1e4,
maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE)
## S3 method for class 'InfRobModel,asUnOvShoot':
optIC(model, risk, upper = 1e4, maxiter = 50,
tol = .Machine$double.eps^0.4, warn = TRUE)
## S3 method for class 'FixRobModel,fiUnOvShoot':
optIC(model, risk, sampleSize, upper = 1e4, maxiter = 50,
tol = .Machine$double.eps^0.4, warn = TRUE, Algo = "A", cont = "left")"RiskType"."fiUnOvShoot" one can choose
between two algorithms for the computation of this risk where the least favorable
contamination is assumed to be left or right of some bound. For more details
we refer to Section 11.3 of Kohl (2005).InfluenceCurve-class, RiskType-classB <- BinomFamily(size = 25, prob = 0.25)
## classical optimal IC
IC0 <- optIC(model = B, risk = asCov())
plot(IC0) # plot IC
checkIC(IC0, B)Run the code above in your browser using DataLab