optRisk(model, risk, ...)
"optRisk"(model, risk)
"optRisk"(model, risk, z.start = NULL, A.start = NULL, upper = 1e4, maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, noLow = FALSE)
"optRisk"(model, risk, sampleSize, upper = 1e4, maxiter = 50, tol = .Machine$double.eps^0.4, warn = TRUE, Algo = "A", cont = "left")RiskType "fiUnOvShoot" one can choose
between two algorithms for the computation of this risk where the least favorable
contamination is assumed to be left or right of some bound. For more details
we refer to Section 11.3 of Kohl (2005).Rieder, H. (1980) Estimates derived from robust tests. Ann. Stats. 8: 106--115.
Rieder, H. (1994) Robust Asymptotic Statistics. New York: Springer.
Kohl, M. (2005) Numerical Contributions to the Asymptotic Theory of Robustness. Bayreuth: Dissertation.
RiskType-classoptRisk(model = NormLocationScaleFamily(), risk = asCov())
Run the code above in your browser using DataLab